import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.utils.qt.autocomplete_widget is deprecated, use glue_qt.utils.autocomplete_widget) instead', GlueDeprecationWarning)
from glue_qt.utils.autocomplete_widget import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.io.qt is deprecated, use glue_qt.io) instead', GlueDeprecationWarning)
from glue_qt.io import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.histogram.qt.data_viewer is deprecated, use glue_qt.viewers.histogram.data_viewer) instead', GlueDeprecationWarning)
from glue_qt.viewers.histogram.data_viewer import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.image.qt.contrast_mouse_mode is deprecated, use glue_qt.viewers.image.contrast_mouse_mode) instead', GlueDeprecationWarning)
from glue_qt.viewers.image.contrast_mouse_mode import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.utils.qt.dialogs is deprecated, use glue_qt.utils.dialogs) instead', GlueDeprecationWarning)
from glue_qt.utils.dialogs import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.table.qt is deprecated, use glue_qt.viewers.table) instead', GlueDeprecationWarning)
from glue_qt.viewers.table import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.scatter.qt.options_widget is deprecated, use glue_qt.viewers.scatter.options_widget) instead', GlueDeprecationWarning)
from glue_qt.viewers.scatter.options_widget import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt.keyboard_shortcuts is deprecated, use glue_qt.app.keyboard_shortcuts) instead', GlueDeprecationWarning)
from glue_qt.app.keyboard_shortcuts import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.subset_facet.qt is deprecated, use glue_qt.dialogs.subset_facet) instead', GlueDeprecationWarning)
from glue_qt.dialogs.subset_facet import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.component_arithmetic.qt.equation_editor is deprecated, use glue_qt.dialogs.component_arithmetic.equation_editor) instead', GlueDeprecationWarning)
from glue_qt.dialogs.component_arithmetic.equation_editor import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.common.qt.toolbar is deprecated, use glue_qt.viewers.common.toolbar) instead', GlueDeprecationWarning)
from glue_qt.viewers.common.toolbar import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.core.data_exporters.qt is deprecated, use glue_qt.core.data_exporters) instead', GlueDeprecationWarning)
from glue_qt.core.data_exporters import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt.edit_subset_mode_toolbar is deprecated, use glue_qt.app.edit_subset_mode_toolbar) instead', GlueDeprecationWarning)
from glue_qt.app.edit_subset_mode_toolbar import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.core.qt.fitters is deprecated, use glue_qt.core.fitters) instead', GlueDeprecationWarning)
from glue_qt.core.fitters import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.autolinker.qt is deprecated, use glue_qt.dialogs.autolinker) instead', GlueDeprecationWarning)
from glue_qt.dialogs.autolinker import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.plugins.dendro_viewer.qt.options_widget is deprecated, use glue_qt.plugins.dendro_viewer.options_widget) instead', GlueDeprecationWarning)
from glue_qt.plugins.dendro_viewer.options_widget import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.scatter.qt is deprecated, use glue_qt.viewers.scatter) instead', GlueDeprecationWarning)
from glue_qt.viewers.scatter import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt.actions is deprecated, use glue_qt.app.actions) instead', GlueDeprecationWarning)
from glue_qt.app.actions import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.profile.qt is deprecated, use glue_qt.viewers.profile) instead', GlueDeprecationWarning)
from glue_qt.viewers.profile import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.io.qt.directory_importer is deprecated, use glue_qt.io.directory_importer) instead', GlueDeprecationWarning)
from glue_qt.io.directory_importer import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.autolinker.qt.autolinker is deprecated, use glue_qt.dialogs.autolinker.autolinker) instead', GlueDeprecationWarning)
from glue_qt.dialogs.autolinker.autolinker import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.core.qt is deprecated, use glue_qt.core) instead', GlueDeprecationWarning)
from glue_qt.core import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.core.qt.layer_artist_model is deprecated, use glue_qt.core.layer_artist_model) instead', GlueDeprecationWarning)
from glue_qt.core.layer_artist_model import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.common.qt.data_viewer_with_state is deprecated, use glue_qt.viewers.common.data_viewer_with_state) instead', GlueDeprecationWarning)
from glue_qt.viewers.common.data_viewer_with_state import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.utils.qt.widget_properties is deprecated, use glue_qt.utils.widget_properties) instead', GlueDeprecationWarning)
from glue_qt.utils.widget_properties import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.core.data_exporters.qt.dialog is deprecated, use glue_qt.core.data_exporters.dialog) instead', GlueDeprecationWarning)
from glue_qt.core.data_exporters.dialog import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.matplotlib.qt.compute_worker is deprecated, use glue_qt.viewers.matplotlib.compute_worker) instead', GlueDeprecationWarning)
from glue_qt.viewers.matplotlib.compute_worker import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.image.qt.slice_widget is deprecated, use glue_qt.viewers.image.slice_widget) instead', GlueDeprecationWarning)
from glue_qt.viewers.image.slice_widget import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt.versions is deprecated, use glue_qt.app.versions) instead', GlueDeprecationWarning)
from glue_qt.app.versions import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt.terminal is deprecated, use glue_qt.app.terminal) instead', GlueDeprecationWarning)
from glue_qt.app.terminal import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt.mdi_area is deprecated, use glue_qt.app.mdi_area) instead', GlueDeprecationWarning)
from glue_qt.app.mdi_area import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.histogram.qt.layer_artist is deprecated, use glue_qt.viewers.histogram.layer_artist) instead', GlueDeprecationWarning)
from glue_qt.viewers.histogram.layer_artist import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.matplotlib.qt.widget is deprecated, use glue_qt.viewers.matplotlib.widget) instead', GlueDeprecationWarning)
from glue_qt.viewers.matplotlib.widget import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.image.qt.layer_style_editor is deprecated, use glue_qt.viewers.image.layer_style_editor) instead', GlueDeprecationWarning)
from glue_qt.viewers.image.layer_style_editor import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.utils.qt.delegates is deprecated, use glue_qt.utils.delegates) instead', GlueDeprecationWarning)
from glue_qt.utils.delegates import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.histogram.qt is deprecated, use glue_qt.viewers.histogram) instead', GlueDeprecationWarning)
from glue_qt.viewers.histogram import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.image.qt.layer_style_editor_subset is deprecated, use glue_qt.viewers.image.layer_style_editor_subset) instead', GlueDeprecationWarning)
from glue_qt.viewers.image.layer_style_editor_subset import *  # noqa



# -*- coding: utf-8 -*-
#
# Glue documentation build configuration file

import os
from pkg_resources import get_distribution

# -- General configuration ----------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
needs_sphinx = '1.6'

# Add any Sphinx extension module names here, as strings. They can be extensions
# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = ['sphinx.ext.autodoc',
              'sphinx.ext.todo',
              'sphinx.ext.coverage',
              'sphinx.ext.mathjax',
              'sphinx.ext.viewcode',
              'sphinx.ext.intersphinx',
              'numpydoc',
              'sphinx_automodapi.automodapi',
              'sphinx_automodapi.smart_resolver']

# Workaround for RTD where the default encoding is ASCII
if os.environ.get('READTHEDOCS') == 'True':
    import locale
    locale.setlocale(locale.LC_ALL, 'C.UTF-8')

intersphinx_cache_limit = 10     # days to keep the cached inventories
intersphinx_mapping = {
    'python': ('https://docs.python.org/3.7', None),
    'matplotlib': ('https://matplotlib.org', None),
    'numpy': ('https://numpy.org/doc/stable/', None),
    'astropy': ('https://docs.astropy.org/en/stable/', None),
    'echo': ('https://echo.readthedocs.io/en/latest/', None),
    'pandas': ('https://pandas.pydata.org/pandas-docs/stable/', None),
}

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix of source filenames.
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = u'Glue'
copyright = u'2012-2019, Chris Beaumont, Thomas Robitaille, Michelle Borkin'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
version = release = get_distribution('glue-core').version

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = ['_build', '_templates', '.eggs']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# -- Options for HTML output --------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
try:  # use ReadTheDocs theme, if installed
    import sphinx_rtd_theme
    html_theme = 'sphinx_rtd_theme'
    html_theme_path = [sphinx_rtd_theme.get_html_theme_path(), ]
except ImportError:
    pass

# The name of an image file (relative to this directory) to place at the top
# of the sidebar.
html_logo = '_static/logo.png'

# The name of an image file (within the static path) to use as favicon of the
# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
# pixels large.
# html_favicon = None

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# Output file base name for HTML help builder.
htmlhelp_basename = 'Gluedoc'

# -- Options for LaTeX output -------------------------------------------------

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, documentclass [howto/manual]).
latex_documents = [
    ('index', 'Glue.tex', u'Glue Documentation',
     u'Chris Beaumont, Thomas Robitaille, Michelle Borkin', 'manual'),
]

# -- Options for manual page output -------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    ('index', 'glue', u'Glue Documentation',
     [u'Chris Beaumont, Thomas Robitaille, Michelle Borkin'], 1)
]

# -- Options for Texinfo output -----------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    ('index', 'Glue', u'Glue Documentation',
     u'Chris Beaumont, Thomas Robitaille, Michelle Borkin',
     'Glue', 'One line description of project.', 'Miscellaneous'),
]

# -- Additional options------- ------------------------------------------------

todo_include_todos = True
autoclass_content = 'both'

nitpick_ignore = [('py:class', 'glue.viewers.histogram.layer_artist.HistogramLayerBase'),
                  ('py:class', 'glue.viewers.scatter.layer_artist.ScatterLayerBase'),
                  ('py:class', 'glue.viewers.image.layer_artist.ImageLayerBase'),
                  ('py:class', 'glue.viewers.image.layer_artist.RGBImageLayerBase'),
                  ('py:class', 'glue.viewers.image.state.BaseImageLayerState')]

viewcode_follow_imported_members = False

numpydoc_show_class_members = False
autosummary_generate = True
automodapi_toctreedirnm = 'api'

linkcheck_ignore = [r'https://s3.amazonaws.com']
linkcheck_retries = 5
linkcheck_timeout = 10



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.plugins.tools.pv_slicer.qt.pv_slicer is deprecated, use glue_qt.plugins.tools.pv_slicer.pv_slicer) instead', GlueDeprecationWarning)
from glue_qt.plugins.tools.pv_slicer.pv_slicer import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt.layer_tree_widget is deprecated, use glue_qt.app.layer_tree_widget) instead', GlueDeprecationWarning)
from glue_qt.app.layer_tree_widget import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.core.qt.dialogs is deprecated, use glue_qt.core.dialogs) instead', GlueDeprecationWarning)
from glue_qt.core.dialogs import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.icons.qt.helpers is deprecated, use glue_qt.icons.helpers) instead', GlueDeprecationWarning)
from glue_qt.icons.helpers import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.matplotlib.qt.axes_editor is deprecated, use glue_qt.viewers.matplotlib.axes_editor) instead', GlueDeprecationWarning)
from glue_qt.viewers.matplotlib.axes_editor import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.utils.qt.python_list_model is deprecated, use glue_qt.utils.python_list_model) instead', GlueDeprecationWarning)
from glue_qt.utils.python_list_model import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.qglue is deprecated, use glue_qt.qglue) instead', GlueDeprecationWarning)
from glue_qt.qglue import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.link_editor.qt.data_graph is deprecated, use glue_qt.dialogs.link_editor.data_graph) instead', GlueDeprecationWarning)
from glue_qt.dialogs.link_editor.data_graph import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.app.qt is deprecated, use glue_qt.app) instead', GlueDeprecationWarning)
from glue_qt.app import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.utils.qt.colors is deprecated, use glue_qt.utils.colors) instead', GlueDeprecationWarning)
from glue_qt.utils.colors import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.viewers.common.qt.tool is deprecated, use glue_qt.viewers.common.tool) instead', GlueDeprecationWarning)
from glue_qt.viewers.common.tool import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.common.qt.component_tree_widget is deprecated, use glue_qt.dialogs.common.component_tree_widget) instead', GlueDeprecationWarning)
from glue_qt.dialogs.common.component_tree_widget import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.dialogs.component_manager.qt is deprecated, use glue_qt.dialogs.component_manager) instead', GlueDeprecationWarning)
from glue_qt.dialogs.component_manager import *  # noqa



import warnings
from glue.utils.error import GlueDeprecationWarning
warnings.warn('Importing from glue.io.qt.subset_mask is deprecated, use glue_qt.io.subset_mask) instead', GlueDeprecationWarning)
from glue_qt.io.subset_mask import *  # noqa
